@@ -1,15 +1,13 @@
 import random
 from datetime import timedelta
 
-from django.conf import settings
 from django.contrib.auth.models import User, Permission, Group
 from django.core.mail import EmailMultiAlternatives
 from django.template.loader import render_to_string
 from django.utils import timezone
 from knox.models import AuthToken
 from rest_framework import serializers
-from Crypto.Cipher import AES
-import base64
+from utils.functions.functions import encrypt, decrypt
 import crypt
 import string
 
@@ -48,7 +46,8 @@ def ask_restore_password_account_user(
         else:
             extended_user = ExtendedUser.objects.create(user=user)
         now = timezone.now()
-        extended_user.registration_token = encrypt(generate_word(30))
+        word = generate_word(30)
+        extended_user.registration_token = encrypt(word)
         extended_user.registration_expiration = now + timedelta(days=2)
         extended_user.save()
 
@@ -120,7 +119,7 @@ def validate_account_user(
     expired_link = True
     if not was_activated:
         if hasattr(user, 'extended_user'):
-            same_activation_key = user.extended_user.registration_token == encrypt(activation_key)
+            same_activation_key = decrypt(user.extended_user.registration_token) == activation_key
         if same_activation_key:
             expired_link = timezone.now().date() > user.extended_user.registration_expiration
             if expired_link:
@@ -159,7 +158,7 @@ def set_restored_password(
         message = 'Este link ya ha sido utilizado, o no sirve para restaurar contraseña'
         return message, True
 
-    same_activation_key = user.extended_user.registration_token == encrypt(activation_key)
+    same_activation_key = decrypt(user.extended_user.registration_token) == activation_key
     expired_link = timezone.now().date() > user.extended_user.registration_expiration
     if same_activation_key:
         if expired_link:
@@ -177,34 +176,6 @@ def set_restored_password(
     return message, error
 
 
-def encrypt(raw_text: str) -> str:
-    if not raw_text:  # pragma: no cover
-        return ''
-    key = settings.KEY_ENCRY
-    vector = settings.VECTOR_ENCRY
-    if len(key) not in [16, 24, 32]:  # pragma: no cover
-        raise serializers.ValidationError('La contraseña debe ser de 16,24 o 32 caracteres')
-    if len(vector) != 16:  # pragma: no cover
-        raise serializers.ValidationError('El vector debe tener 16 caracteres')
-    obj = AES.new(key, AES.MODE_CFB, vector)
-    ciphertext = base64.b64encode(obj.encrypt(raw_text)).decode("utf-8")
-    return ciphertext.strip()
-
-
-def decrypt(enc: str) -> str:
-    if not enc:  # pragma: no cover
-        return ''
-    key = settings.KEY_ENCRY
-    vector = settings.VECTOR_ENCRY
-    if len(key) not in [16, 24, 32]:  # pragma: no cover
-        raise serializers.ValidationError('La contraseña debe ser de 16,24 o 32 caracteres')
-    if len(vector) != 16:  # pragma: no cover
-        raise serializers.ValidationError('El vector debe tener 16 caracteres')
-    obj2 = AES.new(key, AES.MODE_CFB, vector)
-    decrypted_text = obj2.decrypt(base64.b64decode(enc)).decode("utf-8")
-    return decrypted_text
-
-
 def set_security_pin(user_id: int, raw_pin: str) -> [User, str]:
     user = User.objects.get(pk=user_id)
     if hasattr(user, 'extended_user'):
